import { useObservableState } from '@equinor/fusion-observable/react';
import { useMemo } from 'react';
import { useAppProvider } from './useAppProvider';
/**
 * React Hook - Get apps from framework
 * @param args Object with filterByCurrentUser: boolean
 * @returns Object {apps, isLoading, error} where apps is Array of ApplicationManifest, isLoading is a boolean on observable complete
 * @since 7.1.1
 */
export const useApps = (args) => {
    const provider = useAppProvider();
    const { filterByCurrentUser } = args || {};
    const { value: apps, complete, error, } = useObservableState(useMemo(() => provider.getAppManifests(filterByCurrentUser ? { filterByCurrentUser } : undefined), [provider, filterByCurrentUser]));
    return { apps, isLoading: !complete, error };
};
export default useApps;
//# sourceMappingURL=useApps.js.map